pub struct MattermostBot { /* private fields */ }Implementations
Sourceimpl MattermostBot
impl MattermostBot
Sourcepub fn new() -> Result<Self>
pub fn new() -> Result<Self>
Create a MattermostBot using env variables for url and token.
Errors
Returns Error::EnvVarMissing if the MATTERMOST_URL or MATTERMOST_TOKEN environment variable is
missing.
Returns Error::MattermostApi if the value of MATTERMOST_URL cannot be parsed into a
url::Url
pub fn add_command<H, Args>(self, name: &str, handler: H) -> Selfwhere
H: IntoCommand<Args>,
pub fn add_admin_command<H, Args>(self, name: &str, handler: H) -> Selfwhere
H: IntoCommand<Args>,
pub fn add_admin(self, name: String) -> Self
pub fn add_admins(self, names: Vec<String>) -> Self
Sourcepub async fn listen(self) -> Result<()>
pub async fn listen(self) -> Result<()>
Connect to the websocket API on the instance and listen for incoming events.
This method loops, sending messages received from the websocket connection to the passed handler.
Errors
Returns Error::MattermostApi if there’s a problem with setting up the websocket
connection.